Mattel Aquarius - Wikipedia

# Mattel Aquarius

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search
Home computer

| This article needs additional citations for verification. Please help improve this article by adding citations to reliable sources. Unsourced material may be challenged and removed. Find sources: "Mattel Aquarius" – news · newspapers · books · scholar · JSTOR (July 2019) (Learn how and when to remove this template message)

Mattel Aquarius
Type | Home computer
Release date | June 1983 (1983-06)
Introductory price | 160 US$ (today $415.74)
Discontinued | October 1983 (1983-10)[1]
Media | Cassette tape, ROM Cartridge
Operating system | Microsoft BASIC
CPU | Zilog Z80A @ 3.5 MHz
Memory | 4KB RAM (expandable to 20KB), 8KB ROM
Input | Keyboard
Predecessor | Intellivision
Successor | Aquarius II

Aquarius is a home computer designed by Radofin and released by Mattel Electronics in 1983. Based on the Zilog Z80 microprocessor, the system has a rubber chiclet keyboard, 4K of RAM, and a subset of Microsoft BASIC in ROM. It connects to a television set for audio and visual output, and uses a cassette tape recorder for secondary data storage. A limited number of peripherals, such as a 40-column thermal printer, a 4-color printer/plotter, and a 300 baud modem, were released. The Aquarius was discontinued in October 1983, only a few months after it was launched.

## History[edit]

The Aquarius with attached expansion block including 4KB RAM expansion and game cartridge inserted, controllers, and tape Data Recorder
The back of the Aquarius, showing connectors for TV out, an external cassette drive and printer.

Looking to compete in the home computer market, Mattel Electronics turned to Radofin, the Hong Kong based manufacturer of their Intellivision consoles. Radofin had designed two computer systems. Internally they were known as "Checkers" and the more sophisticated "Chess". Mattel contracted for these to become the Aquarius and Aquarius II, respectively. Aquarius was announced in 1982 and finally released in June 1983, at a price of $160. Production ceased four months later because of poor sales. Mattel paid Radofin to take back the marketing rights. Four other companies: CEZAR Industries, CRIMAC, New Era Incentives, and Bentley Industries also marketed the unit and accessories.

The Aquarius was often bundled with the Mini-Expander peripheral, which added game pads, an additional cartridge port for memory expansion, and the AY-3-8914 sound chip. Other peripherals were the Data recorder, 40 column thermal printer, 4K and 16K ram carts. Less common first party peripherals include a 300 baud cartridge modem, 32k RAM cart, 4 color plotter, and Quick Disk drive.

Although less expensive than the Texas Instruments TI-99/4A and Commodore VIC-20, the Aquarius had comparatively weak graphics and limited memory. Internally, Mattel programmers adopted Bob Del Principe's mock slogan, "Aquarius -a system for the seventies".[2] Of the 32 software titles Mattel announced for the unit, only 21 were released, most of which were ports of Intellivision games. Because of the hardware limitations of the Aquarius,the quality of many games suffered. There was such a lack of programmable graphics that Mattel added a special character set, so the games could at least use character graphics.

As a magazine of the time put it, "The Aquarius suffered one of the shortest lifespans of any computer—it was discontinued by Mattel almost as soon as it hit store shelves, a victim of the 1983 home computer price wars."[3] Just after the release of the Aquarius, Mattel announced plans for the Aquarius II, and there is evidence that the Aquarius II reached the market in small numbers,[4][5] but was also not a commercial success.

## Technical specifications[edit]

Motherboard

- CPU: Zilog Z80 @ 3.5 MHz
- Memory: 4K RAM, expandable to 20K RAM; 8K ROM
- Keyboard: 48-key rubber chiclet keyboard
- Display: TEA1002 chip, generating 320 x 192 pixels (all available within borders), 40x24 text (8 x 8 pixel character block), 80x72 addressable graphics, 16 colors
- Sound: One voice, expandable to four voices
- Ports: Television, cartridge/expansion, tape recorder, printer
- PSU: Non-removable external power supply hard-wired into case providing 8.8 / 16 / 19 VDC

## Interfacing[edit]

The Aquarius manual did not contain details of any of the ports available. The cassette port although using the same 5-Pin DIN 41524 connector as the TRS-80, did not have the same pin out and thus was incompatible with readily available cables for the TRS-80, even though they physically fit the sockets on both the computer and cassette player. The Aquarius branded cassette deck came with the appropriate cable.[6]

The cassette port a 5-pin female DIN 41524 connector

Pin | Function Aquarius | Function TRS-80
--- | --- | ---
1 | MIC | REMote
2 | Common Ground | Common Ground
3 | EAR | REMote
4 | Not used | EAR
5 | Not used | MIC

The MIC and EAR connections from the Aquarius each go to the tip/center of one of the two mini-plugs being attached to the recorder; Ground goes to the base/outside of both mini-plugs.[6]

The printer interface is a mini-stereo socket with 3 lines, the same as on the Mattel Entertainment Computer System. The Aquarius printers came with their own cables. The interface conforms to RS-232 serial signal standards (+12VDC/-12VDC), with the knowledge of the pinout it is possible to interface printers with a corresponding RS-232 interface.[6] The serial is fixed to 1200 baud 8N2 and provided both carriage return and line feed commands to the printer, thus the printer needed to be set to not auto feed with carriage return.[6]

Pin out for the connector on the Aquarius:

Aquarius | Function
--- | ---
Tip | Data Out (TxD)
Ring | Printer Busy/Ready (DSR)
Sleeve | Ground (GND)

Typical serial printers had DB-25 interfaces; some had DE-9 interfaces; and, some Radio Shack (RS) printers had round 4-pin female DIN connector serial interfaces (with the pin sockets numbered left-to-right: 4, 3, 2, 1). The proper cable for connecting such a printer is as follows:[6]

    MINI-STEREO PLUG      DB-25    DE-9     RS       FUNCTION

    Tip/Center of Plug    Pin 3    Pin 2    Pin 4    Data to Printer
    Middle of Plug        Pin 20   Pin 4    Pin 2    Printer Busy/Ready
    Base/Outside          Pin 7    Pin 5    Pin 3    Signal Ground

## Character set[edit]

The following table shows the Mattel Aquarius character set. Each character is shown with a potential Unicode equivalent if available. Space characters are represented by the abbreviations for their names.

Mattel Aquarius[7][8][9]
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0_ 0 | £ 00A3 | ½ 00BD | ¼ 00BC | ¾ 00BE | ÷ 00F7 | © 00A9 | → 2192 | ← 2190 | ↑ 2191 | ↓ 2193 | ↗ 2197 | ↙ 2199 | ↘ 2198 | ↖ 2196 | � | �
1_ 16 | � | � | ▮ 25AE | � | � | � | � | � | � | � | ▗ 2597 | ▝ 259D | ▖ 2596 | ▘ 2598 | ▚ 259A | ▄ 2584
2_ 32 | SP 0020 | ! 0021 | " 0022 | # 0023 | $ 0024 | % 0025 | & 0026 | ' 0027 | ( 0028 | ) 0029 | * 002A | + 002B | , 002C | - 002D | . 002E | / 002F
3_ 48 | 0 0030 | 1 0031 | 2 0032 | 3 0033 | 4 0034 | 5 0035 | 6 0036 | 7 0037 | 8 0038 | 9 0039 | : 003A | ; 003B | < 003C | = 003D | > 003E | ? 003F
4_ 64 | @ 0040 | A 0041 | B 0042 | C 0043 | D 0044 | E 0045 | F 0046 | G 0047 | H 0048 | I 0049 | J 004A | K 004B | L 004C | M 004D | N 004E | O 004F
5_ 80 | P 0050 | Q 0051 | R 0052 | S 0053 | T 0054 | U 0055 | V 0056 | W 0057 | X 0058 | Y 0059 | Z 005A | [ 005B | \ 005C | ] 005D | ^ 005E | _ 005F
6_ 96 | ` 0060 | a 0061 | b 0062 | c 0063 | d 0064 | e 0065 | f 0066 | g 0067 | h 0068 | i 0069 | j 006A | k 006B | l 006C | m 006D | n 006E | o 006F
7_ 112 | p 0070 | q 0071 | r 0072 | s 0073 | t 0074 | u 0075 | v 0076 | w 0077 | x 0078 | y 0079 | z 007A | { 007B | | 007C | } 007D | ~ 007E | █ 2588
8_ 128 | ▇ 2587 | ▏ 258F | � | � | 🮏 1FB8F | 🮌 1FB8C | ▒ 2592 | ● 25CF | ▂ 2582 | ▆ 2586 | ♠ 2660 | � | � | � | ▶ 25B6 | ▲ 25B2
9_ 144 | ▁ 2581 | ▉ 2589 | � | � | 🮎 1FB8E | 🮍 1FB8D | ⬤ 2B24 | ▎ 258E | ▍ 258D | ▌ 258C | � | � | � | � | ◀ 25C0 | ▼ 25BC
A_ 160 | NBSP 00A0 | 1FB00 | 1FB01 | 1FB02 | 1FB03 | 1FB04 | 1FB05 | 1FB06 | 1FB07 | 1FB08 | 1FB09 | 1FB0A | 1FB0B | 1FB0C | 1FB0D | 1FB0E
B_ 176 | 1FB0F | 1FB10 | 1FB11 | 1FB12 | 1FB13 | 258C | 1FB14 | 1FB15 | 1FB16 | 1FB17 | 1FB18 | 1FB19 | 1FB1A | 1FB1B | 1FB1C | 1FB1D
C_ 192 | ◢ 25E2 | ◣ 25E3 | � | ▊ 258A | ▪ 25AA | ♦ 2666 | · 00B7 | � | ┼ 253C | � | ╱ 2571 | � | ┴ 2534 | ├ 251C | ┐ 2510 | └ 2514
D_ 208 | � | � | � | � | ♥ 2665 | ♣ 2663 | │ 2502 | � | ╳ 2573 | � | ╲ 2572 | � | ┬ 252C | ┤ 2524 | ┌ 250C | ┘ 2518
E_ 224 | 1FB1E | 1FB1F | 1FB20 | 1FB21 | 1FB22 | 1FB23 | 1FB24 | 1FB25 | 1FB26 | 1FB27 | 2590 | 1FB28 | 1FB29 | 1FB2A | 1FB2B | 1FB2C
F_ 240 | 1FB2D | 1FB2E | 1FB2F | 1FB30 | 1FB31 | 1FB32 | 1FB33 | 1FB34 | 1FB35 | 1FB36 | 1FB37 | 1FB38 | 1FB39 | 1FB3A | 1FB3B | █ 2588

Letter Number Punctuation Symbol Other Undefined � No Unicode equivalent

## List of games[edit]

Title | Publisher | Release date
--- | --- | ---
Advanced Dungeons & Dragons: Treasure of Tarmin | Mattel | 1982
Aliens | Add On Electronics | 1983
Aquapack 1 (Snake, Breakout, Moon Shuttle) | Apocalypse Software | ????
Astrosmash | Mattel | 1983
Aquariworm | Cronosoft | 2020
Battle Zone | Add On Electronics | 1984
Bounder | Add On Electronics | 1984
Bomb Catcher II | Cronosoft | 2021
Breakout | Add On Electronics | 1984
Burger Time | Data East | 1982
Chess (Dick Smith Electronics) | Dick Smith Electronics | 1983
Chess (Mattel) | Mattel | 1983
Chuckman | Add On Electronics | 1983
D-Fenders | Add On Electronics | 1983
Deathrace | Apocalypse Software | ????
Demo Cassette (Stalactites, Macho-Man, Torment, Cute Cubes, Alien Quest, Mad Mould) | Radofin Electronics | 1983
Disco Fever | Add On Electronics | 1984
Ed-On | Add On Electronics | 1983
First Adventure | Digital Output | 1984
Games Pack 1 (Stalactites, Macho-Man, Othello, Mutants) | Add On Electronics | 1983
Games Pack 2 (Bounder, Local Bomber, Breakout, Night Driver) | Custom Cables International | 1984
Games Pack 3 (Metior, Sheepdog, Mastermind, Depthcharge) | Custom Cables International | 1984
Games Pack 4 (Painter, Pontoon, Grand Prix, Alien Storm) | Custom Cables International | 1984
GamesTape (Dodge It, Trojan Dragon, Death Trap, Tablets of Hippocrates) | Fawkes Computing | 1984
Gamespack 1 (Snake, Masterguess, Symon, Bomber, Hi-Lo) | Processor Software | 1984
Gamespack 2 (Collector, Blocked!, Rocket Run, Minefield, Air-Defence) | Processor Software | 1984
Grid Bug | Add On Electronics | 1983
Hopper | Microdeal | 1984
Invaders | Dick Smith Electronics | 1984
Kronos Europea Cassette (Gamble, Gunfight, Mad Mould, Outline) | Radofin Electronics | 1984
Maths Armada | Dick Smith Electronics | 1984
Mazantics | Add On Electronics | 1983
Melody Chase | Mattel | 1983
Millypede | Add On Electronics | 1983
Mower Man | Add On Electronics | 1984
N-Vaders | Add On Electronics | 1983
Night Stalker | Mattel | 1982
Outpack 1 (Snake, Masterguess, Symon, Bomber, Hi-Lo) | Digital Output | 1984
Outpack 2 (Collector, Blocked, Rocket Run, Minefield, Air-Defence) | Digital Output | 1984
Outpack 3 (Gunfight, Gambler, Moonlander, Tracker, Nim) | Digital Output | 1984
Outpack 4 (Super Slot, Golf, Invasion, Killer Sub, Survival) | Digital Output | 1984
Outpack 5 (Timetrap, Gro-Worm, Wampus Gold, Bumpers, Space Shoot) | Digital Output | 1984
Pac Mr | Add On Electronics | 1983
Phrogger | Add On Electronics | 1984
Postman Pot | Add On Electronics | 1984
Rally Driver | Micro Mart Software | 1984
Scramble | Micro Mart Software | 1984
Snafu | Mattel | 1982
Space Ram | Dick Smith Electronics | 1984
Space Speller | Mattel | 1983
Tracker | Digital Output | ????
Tron Deadly Discs | Mattel | 1982
Utopia | Mattel | 1982
Zero In | Mattel | 1983
Zorgon's Kingdom | Romik Software | 1984

## References[edit]

1. ^ Page 49, InfoWorld, 23 Jan 1984, ...John Allen, president of The Lisp Company...announcing TLC Logo, which could run on the Mattel Aquarius...Today, the Mattel Aquarius is virtually off the market...
2. ^
   Klooster, Erik. "Mattel Aquarius - home computer with the shortest career". computermuseum.50megs.com. Retrieved 2020-01-28. Besides that, the Mini Expander was equipped with the same sound chip (AY-3-8914) as the Intellivision. But that didn't appeal to the programmers: they almost considered it as a punishment to develop a game for the Aquarius. Programmer Bob Del Principe even invented this cynical slogan: 'Aquarius - system for the seventies!'
3. ^ "Mattel Aquarius Benchmark". COMPUTE! Magazine, April 1985, p18. April 1985. Retrieved April 4, 2020.
4. ^ Mattel Aquarius II at old-computers.com Archived 2006-11-19 at the Wayback Machine, retrieved October 6, 2006
5. ^ Mattel Aquarius at perso.orange.fr[dead link] (translated via Babel Fish, original article), retrieved October 6, 2006 Archived March 11, 2007, at the Wayback Machine
6. ^ a b c d e Horvat/Parrish, “Mattel Aquarius FAQ,” May 6, 2001.
7. ^ "Mattel Aquarius Homecomputer system".
8. ^ "Figure 4. Mattel Aquarius character set" (PDF), L2/19-025: Proposal to add characters from legacy computers and teletext to the UCS, 2019-01-04, p. 20
9. ^ Sources for L2/19-025 (PDF), 2019-01-04

## External links[edit]

| Wikimedia Commons has media related to Mattel Aquarius.

- http://www.vdSteenoven.com/aquarius/
- http://oldcomputers.net/aquarius.html
- http://www.zophar.net/aquarius/
- The Dot Eaters entry on Aquarius and the Intellivision
- Sample videos of most Mattel Aquarius programs
- The Mattel Aquarius at The Centre for Computing History
- Mattel Aquarius Software Collection playable for free in the browser at the Internet Archive

Listen to this article (5 minutes)
This audio file was created from a revision of this article dated 28 April 2013 (2013-04-28), and does not reflect subsequent edits.
Retrieved from "https://en.wikipedia.org/w/index.php?title=Mattel_Aquarius&oldid=1046114970"
Categories:

- Mattel
- Z80-based home computers
- Home computers
- Computer-related introductions in 1983

Hidden categories:

- Webarchive template wayback links
- All articles with dead external links
- Articles with dead external links from April 2017
- Articles with short description
- Short description is different from Wikidata
- Articles needing additional references from July 2019
- All articles needing additional references
- Commons category link is on Wikidata
- Articles with hAudio microformats
- Spoken articles